@@ -26,22 +26,6 @@ function (xyz, zcol = 3, xcol = 1, ycol = 2)
     ymin = min(yy)
     ymax = max(yy)
     yrange = ymax - ymin
-    pin = par("pin")
-    pinratio = pin[1]/pin[2]
-    if (ratio > pinratio) {
-        yrange = yrange * ratio/pinratio
-        ny.new = max(round(yrange/dy), ny)
-        ymin = min(yy) - dy * round((ny.new - ny)/2)
-        ymax = ymin + dy * (ny.new - 1)
-        ny = ny.new
-    }
-    else {
-        xrange = xrange * pinratio/ratio
-        nx.new = max(round(xrange/dx), nx)
-        xmin = min(xx) - dx * round((nx.new - nx)/2)
-        xmax = xmin + dx * (nx.new - 1)
-        nx = nx.new
-    }
     zz = matrix(NA, nrow = nx, ncol = ny)
     xx = seq(xmin, xmax, dx)
     yy = seq(ymin, ymax, dy)
